/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * Debugging routines.
 **/

#ifndef __KIBA_DEBUG_H
#define __KIBA_DEBUG_H

#include <glib.h>

G_BEGIN_DECLS

#define DEBUG(level, format, args...) kiba_debug_message(level, __FILE__, __LINE__, format, ##args)
#define DEBUG_MISC(format, args...) DEBUG(KIBA_DEBUG_MISC, format, ##args)
#define DEBUG_INFO(format, args...) DEBUG(KIBA_DEBUG_INFO, format, ##args)
#define DEBUG_WARNING(format, args...) DEBUG(KIBA_DEBUG_WARNING, format, ##args)
#define DEBUG_ERROR(format, args...) DEBUG(KIBA_DEBUG_ERROR, format, ##args)
#define DEBUG_FATAL(format, args...) DEBUG(KIBA_DEBUG_FATAL, format, ##args)

/**
 * Debug levels.
 */
enum {
	KIBA_DEBUG_MISC = 0, /**< General chatter.               */
	KIBA_DEBUG_INFO,     /**< General operation Information. */
	KIBA_DEBUG_WARNING,  /**< Warnings.                      */
	KIBA_DEBUG_ERROR,    /**< Errors.                        */
	KIBA_DEBUG_FATAL     /**< Fatal errors.                  */
};

void kiba_debug_init (void);

gboolean kiba_debug_is_enabled();

void kiba_debug_message (int          level,
			 const char  *file,
			 signed int   line,
			 const char *format,
			 ...);

G_END_DECLS

#endif
