/*
 *  Copyright (C) 2006-2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * SECTION:kiba-desktop-editor
 * @short_description: Editor for .desktop files.
 * @see_also:#KibaDesktopIcon
 *
 * Editor for .desktop files.
 */

#ifndef __KIBA_DESKTOP_EDITOR_H__
#define __KIBA_DESKTOP_EDITOR_H__

#include <gtk/gtk.h>
#include <kiba-info-win.h>

G_BEGIN_DECLS

#define KIBA_TYPE_DESKTOP_EDITOR           (kiba_desktop_editor_get_type ())
#define KIBA_DESKTOP_EDITOR(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_DESKTOP_EDITOR, KibaDesktopEditor))
#define KIBA_DESKTOP_EDITOR_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_DESKTOP_EDITOR,  KibaDesktopEditorClass))
#define KIBA_IS_DESKTOP_EDITOR(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_DESKTOP_EDITOR))
#define KIBA_IS_DESKTOP_EDITOR_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_DESKTOP_EDITOR))
#define KIBA_DESKTOP_EDITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_DESKTOP_EDITOR, KibaDesktopEditorClass))

typedef struct _KibaDesktopEditor       KibaDesktopEditor;
typedef struct _KibaDesktopEditorClass  KibaDesktopEditorClass;

typedef struct {
	KibaDesktopEditor *editor;       /**< pointer to the desktop editor */
	char              *path;         /**< path of the desktop file */

	char              *name;         /**< Name desktop key */
	char              *description;  /**< Description desktop key */
	char              *exec;         /**< Exec desktop key */
	char              *group;        /**< Group desktop key */
	char              *icon;         /**< Icon desktop key */

	gboolean           icon_changed;
}KibaDesktopEditorFile;

struct _KibaDesktopEditor {
	GObjectClass   parent_instance;

	GtkWidget       *win;
	GtkWidget       *entry;
	GtkWidget       *combobox;
	GtkWidget       *image;
	GtkWidget       *name_entry;
	GtkWidget       *description_entry;
	GtkWidget       *group_entry;
	GtkWidget       *exec_entry;
	GtkWidget       *icon_chooser;

	GList           *desktop_files;        /**< list of all KibaDesktopEditorFile's */
	char            *path;                 /**< path to KibaDesktopEditorFile(s) */

	KibaDesktopEditorFile *active_file;
};

struct _KibaDesktopEditorClass {
	GObjectClass  parent_class;

	/* signals */
	void (* file_saved) (KibaDesktopEditor *editor,
			     const char        *file_path);
};

KibaDesktopEditor* kiba_desktop_editor_new (const char *app_path);

void kiba_desktop_editor_activate_file (KibaDesktopEditor *editor,
                                        KibaDesktopEditorFile *file);

G_END_DECLS

#endif
