/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * SECTION:kiba-desktop-icon
 * @short_description: Class representing a .desktop file.
 * @see_also:#KibaDesktopEditor
 *
 * Class representing a .desktop file.
 */

#ifndef __KIBA_DESKTOP_ICON_H__
#define __KIBA_DESKTOP_ICON_H__

#include <gtk/gtk.h>
#include <glib.h>

#include <kiba-cairo-utils.h>

G_BEGIN_DECLS

typedef struct _KibaDesktopIcon         KibaDesktopIcon;
typedef struct _KibaDesktopIconClass    KibaDesktopIconClass;

#define KIBA_TYPE_DESKTOP_ICON           (kiba_desktop_icon_get_type ())
#define KIBA_DESKTOP_ICON(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_DESKTOP_ICON, KibaDesktopIcon))
#define KIBA_DESKTOP_ICON_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_DESKTOP_ICON,  KibaDesktopIconClass))
#define KIBA_IS_DESKTOP_ICON(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_DESKTOP_ICON))
#define KIBA_IS_DESKTOP_ICON_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_DESKTOP_ICON))
#define KIBA_DESKTOP_ICON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_DESKTOP_ICON, KibaDesktopIconClass))

// some custom desktop keys
#define KIBA_KEY_FILE_DESKTOP_KEY_GROUP "LauncherGroup"
#define KIBA_KEY_FILE_DESKTOP_KEY_CLASS "Class"

// default values for custom desktop keys
#define KIBA_KEY_FILE_DESKTOP_DEFAULT_GROUP "NotGrouped"
#define KIBA_KEY_FILE_DESKTOP_DEFAULT_CLASS "NotYetLaunched"

typedef enum {
	KIBA_DESKTOP_TYPE_APPLICATION = 0,
	KIBA_DESKTOP_TYPE_LINK,
	KIBA_DESKTOP_TYPE_DIRECTORY,
	KIBA_DESKTOP_TYPE_REMINDER,
	KIBA_DESKTOP_TYPE_INVALID
}KibaDesktopIconType;

typedef struct {
	KibaDesktopIconType type;

	gchar *uri;
	gchar *name;
	gchar *comment;
	gchar *exec;
	gchar *icon;
	gchar *group;
}KibaDesktopEntry;

struct _KibaDesktopIcon {
	GObject parent;
	
	KibaDesktopEntry entry;
};

struct _KibaDesktopIconClass {
	GObjectClass parent_class;
	
	void (* file_changed) (KibaDesktopIcon *icon, const gchar *uri);
};

KibaDesktopIcon*
kiba_desktop_icon_new (void);

gboolean
kiba_desktop_icon_set_file (KibaDesktopIcon *desktop_icon,
		const gchar *desktop_file);

const gchar*
kiba_desktop_icon_get_file (KibaDesktopIcon *desktop_icon);

void
kiba_desktop_icon_write_file (KibaDesktopIcon *desktop_icon);

G_END_DECLS

#endif
