/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * SECTION:kiba-progress
 * @short_description: Shows progress on #KibaObject's.
 * @see_also:#KibaObject
 *
 * Shows progress on #KibaObject's.
 */

#ifndef __KIBA_PROGRESS_H__
#define __KIBA_PROGRESS_H__

#include <glib.h>
#include <cairo.h>

#include <kiba-types.h>

G_BEGIN_DECLS

typedef struct _KibaProgress KibaProgress;
typedef struct _KibaProgressClass KibaProgressClass;

#define KIBA_TYPE_PROGRESS           (kiba_progress_get_type ())
#define KIBA_PROGRESS(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_PROGRESS, KibaProgress))
#define KIBA_PROGRESS_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_PROGRESS,  KibaProgressClass))
#define KIBA_IS_PROGRESS(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_PROGRESS))
#define KIBA_IS_PROGRESS_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_PROGRESS))
#define KIBA_PROGRESS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_PROGRESS, KibaProgressClass))

typedef struct {
	KibaRGBA rgba;
	KibaRGBA bg_rgba;
}KibaProgressStyle;

KibaProgress* kiba_progress_new ();

void kiba_progress_set_style (KibaProgress *progress,
                              KibaProgressStyle  style);

KibaProgressStyle kiba_progress_get_style(KibaProgress *progress);

void kiba_progress_draw (KibaProgress *progress,
                         cairo_t *cr);

void kiba_progress_add_object (KibaProgress *progress,
                               KibaObject *object);

void kiba_progress_remove_object (KibaProgress *progress,
                                  KibaObject *object);

gboolean kiba_progress_object_is_running (KibaProgress *progress,
                                          KibaObject *object);

void kiba_progress_object_set_value (KibaProgress *progress,
                                     KibaObject *object,
                                     gint value);

G_END_DECLS

#endif
