/*
 *  Copyright (C) 2008 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * SECTION:kiba-tooltip
 * @short_description: Tooltip for #KibaObject's.
 * @see_also:#KibaObject
 *
 * Tooltip for #KibaObject's.
 */

#ifndef __KIBA_TOOLTIP_
#define __KIBA_TOOLTIP_

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define KIBA_TYPE_TOOLTIP           (kiba_tooltip_get_type ())
#define KIBA_TOOLTIP(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_TOOLTIP, KibaTooltip))
#define KIBA_TOOLTIP_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_TOOLTIP,  KibaTooltipClass))
#define KIBA_IS_TOOLTIP(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_TOOLTIP))
#define KIBA_IS_TOOLTIP_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_TOOLTIP))
#define KIBA_TOOLTIP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_TOOLTIP, KibaTooltipClass))

typedef struct _KibaTooltip       KibaTooltip;
typedef struct _KibaTooltipClass  KibaTooltipClass;

struct _KibaTooltip {
	GtkWindow object;

	char  *file; /**< The pattern file path */
	KibaCornerShape cornerStyle;
	KibaRGBA borderColor;
	KibaRGBA textColor;
	KibaRGBA *gradient;
	gint numColors;
	char *font;
};

struct _KibaTooltipClass {
	GtkWindowClass parent_class;
};

KibaTooltip* kiba_tooltip_new (void);

void kiba_tooltip_set_text(KibaTooltip *tooltip,
                           const char *text);

void kiba_tooltip_set_gradient (KibaTooltip *tooltip,
                                KibaRGBA    *rgba,
                                gint         numColors);

G_END_DECLS

#endif

