/*
 *  Copyright (C) 2006-2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * SECTION:kiba
 * @short_description: Class managing docks.
 * @see_also: #KibaWin,#KibaDock,#KibaObject,#KibaPlugin
 *
 * Manages multiple dock windows.
 */

#ifndef __KIBA_H__
#define __KIBA_H__

#include <gtk/gtk.h>

#include <kiba-win.h>
#include <kiba-plugin.h>
#include <kiba-object.h>
#include <kiba-prefs.h>
#include <kiba-title.h>
#include <kiba-tooltip.h>
#include <kiba-types.h>

G_BEGIN_DECLS

#define KIBA_TYPE           (kiba_get_type ())
#define KIBA(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE, Kiba))
#define KIBA_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA,  KibaClass))
#define KIBA_IS(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE))
#define KIBA_IS_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE))
#define KIBA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE, KibaClass))

typedef struct _Kiba Kiba;
typedef struct _KibaClass KibaClass;

Kiba* kiba_get();

gboolean kiba_add_plugin_object (Kiba *kiba,
                                 KibaPlugin *plugin,
                                 KibaObject *object);

KibaPrefsFile* kiba_get_plugin_config_file (Kiba *kiba,
                                            KibaPlugin *plugin);

KibaPrefsFile* kiba_get_dock_config_file (Kiba *kiba,
                                          KibaDock *dock);

KibaPrefsFile* kiba_get_win_config_file (Kiba *kiba,
                                          KibaWin *win);

KibaWin* kiba_get_plugin_win (Kiba *kiba,
                              KibaPlugin *plugin);

KibaWin* kiba_get_win (Kiba *kiba);

KibaTitle* kiba_get_title (Kiba *kiba);

KibaTooltip* kiba_get_tooltip (Kiba *kiba);

GList* kiba_get_docks(Kiba *kiba);

void kiba_add_config_file (Kiba *kiba,
                           const gchar *configFile);

void kiba_remove_config_file (Kiba *kiba,
                              const gchar *configFile);

void kiba_quit (Kiba *kiba);

G_END_DECLS

#endif
